



#include "RHB_Custom.h"




ClassImp (RHB_Custom)



void  RHB_Custom::InitParams (void) {

  FEventProcessorThread::InitParams ();       // call official function
                                              // and add user specific part :

  this->samples_2 = GetParam ("CH2_SAMPLES"); // get a param already declared

  this->unknowns = new FParamBrutSimple ();  // create new params
  this->neutrons = new FParamBrutSimple ();
  this->gammas   = new FParamBrutSimple ();
  this->unknowns->SetName ("Unknowns");
  this->neutrons->SetName ("Neutrons");
  this->gammas->SetName   ("Gammas");
  this->AddRawParam (this->unknowns);
  this->AddRawParam (this->neutrons);
  this->AddRawParam (this->gammas);
  this->nu = 0;
  this->nn = 0;
  this->ng = 0;
  this->nb_fast      = 30;
  this->charge_thres = 15000.0;
  this->ratio_thres  = 0.85;

}





void RHB_Custom::SetParamValues (void) {

  Double_t qtot  =  0.0;
  Double_t qfast =  0.0;
  Double_t ratio = -1.0;
  Double_t val   =  0.0;
  Int_t    npts  =  0;

  FEventProcessorThread::SetParamValues ();                   //  call official function
                                                              //  and add user specific part :
                                                              //
  if (this->samples_2->IsOn ()) {                             //  when data is ch2 sampler data
    npts = this->samples_2->GetNbValues ();                   //    - get number of samples
    for (int i=0; i<npts; i++) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i);                    //
      qtot += val;                                            //
      if (i < this->nb_fast) qfast += val;                                 //
    }
    if (qtot != 0.0) ratio = qfast / qtot;
    if ((qtot < this->charge_thres) || (ratio > 1.0) || (ratio < 0.0)) {
      this->nu += 1;
      this->unknowns->SetValue (this->nu);                          //    - update custom parameters
    } else if (ratio < this->ratio_thres) {
      this->nn +=1;
      this->neutrons->SetValue (this->nn);                          //    - update custom parameters
    } else {
      this->ng +=1;
      this->gammas->SetValue (this->ng);                          //    - update custom parameters
    }
  }

}



