



#include "RHB_Custom.h"




ClassImp (RHB_Custom)



void  RHB_Custom::InitParams (void) {

  FEventProcessorThread::InitParams ();       // call official function
                                              // and add user specific part :

  this->samples_2 = GetParam ("CH2_SAMPLES"); // get a param already declared

  this->nb_pts    = new FParamBrutSimple ();  // create new params
  this->base_line = new FParamBrutSimple ();  // create new params
  this->charge    = new FParamBrutSimple ();
  this->max       = new FParamBrutSimple ();
  this->min       = new FParamBrutSimple ();
  this->fwhm      = new FParamBrutSimple ();
  this->risetime  = new FParamBrutSimple ();
  this->nb_pts->SetName    ("NbPts");
  this->base_line->SetName ("BaseLine");
  this->charge->SetName    ("Charge");
  this->max->SetName       ("Max");
  this->min->SetName       ("Min");
  this->fwhm->SetName      ("Fwhm");
  this->risetime->SetName  ("RiseTime");
  this->AddRawParam (this->nb_pts);
  this->AddRawParam (this->base_line);
  this->AddRawParam (this->charge);
  this->AddRawParam (this->max);
  this->AddRawParam (this->min);
  this->AddRawParam (this->fwhm);
  this->AddRawParam (this->risetime);

  this->n = 0;
}





void RHB_Custom::SetParamValues (void) {

  Double_t val   =  0.0;
  Double_t max   = -10000.0;
  Double_t min   =  10000.0;
  Double_t q     =  0.0;
  Double_t bl    =  0.0;
  Int_t    nbl   =  10;
  Int_t    n_max =  0;
  Int_t    n_hm1 =  0;
  Int_t    n_hm2 =  0;
  Int_t    n_rt1 =  0;
  Int_t    n_rt2 =  0;
  Int_t    npts  =  0;

  FEventProcessorThread::SetParamValues ();                   //  call official function
                                                              //  and add user specific part :
                                                              //
  if (this->samples_2->IsOn ()) {                             //  when data is ch2 sampler data
    npts = this->samples_2->GetNbValues ();                   //    - get number of samples
    if (this->n < 10) {
      cout << "nbpts=" << npts << endl;
      this->n++;
    }
    for (int i=0; i<npts; i++) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i);                    //
      q += val;
      if (i   < nbl) bl += val;
      if (val < min) min = val;
      if (val > max) {
        max   = val;
        n_max = i;
      }
    }
    bl    = bl / nbl;
    max   = max - bl;
    min   = min - bl;
    q     = q   - bl * npts;
    n_hm1 = 0;
    n_hm2 = npts - 1;
    n_rt1 = 0;
    n_rt2 = npts - 1;
    for (int i=n_max; i<npts; i++) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i) - bl;                    //
      if (val <= max / 2) {
        n_hm2 = i;
        break;
      }
    }
    for (int i=n_max; i>=0; i--) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i) - bl;                    //
      if (val <= max / 2) {
        n_hm1 = i;
        break;
      }
    }
    for (int i=n_max; i>=0; i--) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i) - bl;                    //
      if (val <= max * 0.9) {
        n_rt2 = i;
        break;
      }
    }
    for (int i=n_rt2; i>=0; i--) {                              //    - calculate charges and ratio
      val = this->samples_2->GetValue (i) - bl;                    //
      if (val <= max * 0.1) {
        n_rt1 = i;
        break;
      }
    }
    this->nb_pts->SetValue    (npts);                          //    - update custom parameters
    this->base_line->SetValue (bl);                          //    - update custom parameters
    this->charge->SetValue    (q);                         //
    this->max->SetValue       (max);                         //
    this->min->SetValue       (min);
    this->fwhm->SetValue      (n_hm2 - n_hm1);
    this->risetime->SetValue  (n_rt2 - n_rt1);
  }

}



